@@ -22,7 +22,7 @@
 #       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-VERSION=4.4.17
+VERSION=4.4.19.1
 
 usage() # $1 = exit status
 {
@@ -123,6 +123,7 @@ done
 
 PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/bin:/usr/local/sbin
 
+[ -n "${LIBEXEC:=share}" ]
 #
 # Determine where to install the firewall script
 #
@@ -189,6 +190,7 @@ else
     rm -rf ${DESTDIR}/etc/shorewall-lite
     rm -rf ${DESTDIR}/usr/share/shorewall-lite
     rm -rf ${DESTDIR}/var/lib/shorewall-lite
+    [ "$LIBEXEC" = share ] || rm -rf /usr/share/shorewall-lite/shorecap /usr/share/shorecap
 fi
 
 #
@@ -204,6 +206,8 @@ delete_file ${DESTDIR}/usr/share/shorewall-lite/xmodules
 
 install_file shorewall-lite ${DESTDIR}/sbin/shorewall-lite 0544
 
+eval sed -i \'``s\|g_libexec=.\*\|g_libexec=$LIBEXEC\|\' ${DESTDIR}/sbin/shorewall-lite
+
 echo "Shorewall Lite control program installed in ${DESTDIR}/sbin/shorewall-lite"
 
 #
@@ -225,6 +229,7 @@ echo  "Shorewall Lite script installed in ${DESTDIR}${DEST}/$INIT"
 #
 mkdir -p ${DESTDIR}/etc/shorewall-lite
 mkdir -p ${DESTDIR}/usr/share/shorewall-lite
+mkdir -p ${DESTDIR}/usr/${LIBEXEC}/shorewall-lite
 mkdir -p ${DESTDIR}/var/lib/shorewall-lite
 
 chmod 755 ${DESTDIR}/etc/shorewall-lite
@@ -277,24 +282,24 @@ echo "Common functions linked through ${DESTDIR}/usr/share/shorewall-lite/functi
 # Install Shorecap
 #
 
-install_file shorecap ${DESTDIR}/usr/share/shorewall-lite/shorecap 0755
+install_file shorecap ${DESTDIR}/usr/${LIBEXEC}/shorewall-lite/shorecap 0755
 
 echo
-echo "Capability file builder installed in ${DESTDIR}/usr/share/shorewall-lite/shorecap"
+echo "Capability file builder installed in ${DESTDIR}/usr/${LIBEXEC}/shorewall-lite/shorecap"
 
 #
 # Install wait4ifup
 #
 
 if [ -f wait4ifup ]; then
-    install_file wait4ifup ${DESTDIR}/usr/share/shorewall-lite/wait4ifup 0755
+    install_file wait4ifup ${DESTDIR}/usr/${LIBEXEC}/shorewall-lite/wait4ifup 0755
 
     echo
-    echo "wait4ifup installed in ${DESTDIR}/usr/share/shorewall-lite/wait4ifup"
+    echo "wait4ifup installed in ${DESTDIR}/usr/${LIBEXEC}/shorewall-lite/wait4ifup"
 fi
 
 #
-# Install the Modules file
+# Install the Modules files
 #
 
 if [ -f modules ]; then
@@ -302,6 +307,16 @@ if [ -f modules ]; then
     echo "Modules file installed as ${DESTDIR}/usr/share/shorewall-lite/modules"
 fi
 
+if [ -f helpers ]; then
+    run_install $OWNERSHIP -m 0600 helpers ${DESTDIR}/usr/share/shorewall-lite
+    echo "Helper modules file installed as ${DESTDIR}/usr/share/shorewall-lite/helpers"
+fi
+
+for f in modules.*; do
+    run_install $OWNERSHIP -m 0644 $f ${DESTDIR}/usr/share/shorewall-lite/$f
+    echo "Module file $f installed as ${DESTDIR}/usr/share/shorewall-lite/$f"
+done
+
 #
 # Install the Man Pages
 #
