@@ -26,7 +26,7 @@
 #       You may only use this script to uninstall the version
 #       shown below. Simply run this script to remove Shorewall Firewall
 
-VERSION=4.4.17
+VERSION=4.4.19.1
 
 usage() # $1 = exit status
 {
@@ -72,6 +72,8 @@ else
     VERSION=""
 fi
 
+[ -n "${LIBEXEC:=share}" ]
+
 echo "Uninstalling Shorewall Lite $VERSION"
 
 if qt iptables -L shorewall -n && [ ! -f /sbin/shorewall ]; then
@@ -107,6 +109,7 @@ rm -rf /etc/shorewall-lite-*.bkout
 rm -rf /var/lib/shorewall-lite
 rm -rf /var/lib/shorewall-lite-*.bkout
 rm -rf /usr/share/shorewall-lite
+rm -rf /usr/${LIBEXEC}/shorewall-lite
 rm -rf /usr/share/shorewall-lite-*.bkout
 rm -f  /etc/logrotate.d/shorewall-lite
 
